@@ -153,10 +153,6 @@ class PeUser(BaseModel):
                 user["contract"] = contracts_dict[user["id"]]
                 u = cls(**user)
                 users.append(u)
-                logger.debug(f"User created {u.name}")
-            else:
-                pass
-                logger.warning(f"User withough employment contract {user['name']}")
 
         users = sorted(users, key=lambda user: (getattr(user.contract, sort_key), user.name))
         cls.add_index(users)
@@ -172,6 +168,7 @@ class PeUser(BaseModel):
 
 
 if __name__ == "__main__":
+    """Local testing"""
     import os
     from pprint import pprint
 
